==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/doc/TestUnboundedArrayResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.UnboundedArray;


/**
 * <p>Java class for testUnboundedArrayResponse element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testUnboundedArrayResponse">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types1}UnboundedArray"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}UnboundedArray"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types1}UnboundedArray"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testUnboundedArrayResponse")
public class TestUnboundedArrayResponse {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/doc", required = true)
    protected UnboundedArray _return;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected UnboundedArray y;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected UnboundedArray z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link UnboundedArray }
     *     
     */
    public UnboundedArray getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnboundedArray }
     *     
     */
    public void setReturn(UnboundedArray value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link UnboundedArray }
     *     
     */
    public UnboundedArray getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnboundedArray }
     *     
     */
    public void setY(UnboundedArray value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link UnboundedArray }
     *     
     */
    public UnboundedArray getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnboundedArray }
     *     
     */
    public void setZ(UnboundedArray value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/doc/TestUnboundedArrayResponse.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.UnboundedArray;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types1}UnboundedArray"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}UnboundedArray"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types1}UnboundedArray"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testUnboundedArrayResponse")
public class TestUnboundedArrayResponse {

    @XmlElement(name = "return", required = true)
    protected UnboundedArray _return;
    @XmlElement(required = true)
    protected UnboundedArray y;
    @XmlElement(required = true)
    protected UnboundedArray z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link UnboundedArray }
     *     
     */
    public UnboundedArray getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnboundedArray }
     *     
     */
    public void setReturn(UnboundedArray value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link UnboundedArray }
     *     
     */
    public UnboundedArray getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnboundedArray }
     *     
     */
    public void setY(UnboundedArray value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link UnboundedArray }
     *     
     */
    public UnboundedArray getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnboundedArray }
     *     
     */
    public void setZ(UnboundedArray value) {
        this.z = value;
    }

}
